@@ -10,11 +10,10 @@ from .utils import *
 from .handler import *
 
 
-def create(
-    env: Dict[str, str], make_handler: Callable[[Logger], BaseHandler]
-) -> Executor:
+def create(env: Dict[str, str], make_handler: HandlerFactory) -> Executor:
     # Always handled by the library, pass environment directly
-    instance = Instance(Environment(**env))
+    parsed_env = Environment(**env)
+    instance = Instance(parsed_env)
     instance.wait_for_dapr()
     # Inherit worker specifications and logs from instance
-    return Executor(make_handler, instance)
+    return Executor(not parsed_env.NO_PUBLISH, make_handler, instance)
